@@ -85,9 +85,9 @@ def get_top_terms(tfidf, n):
 
 def doc_to_vec(doc_prep):
     document_vec = {}
-    length = sum(doc_prep.values())
+    document_norm=norm(doc_prep)
     for term in doc_prep:
-        document_vec[term] = doc_prep[term] / length
+        document_vec[term] = doc_prep[term] / document_norm
     return document_vec
 
 
@@ -97,6 +97,9 @@ def get_esa_matrix(top_n, tfidf, concepts):
         esa_matrix[concept] = {term : 0.0 for term in list(top_n[concept])}
         for term  in list(top_n[concept]):
             esa_matrix[concept][term] = tfidf.loc[concept, term]
+        concept_norm= norm(esa_matrix[concept])
+        for term in list(top_n[concept]):
+            esa_matrix[concept][term] = esa_matrix[concept][term]/concept_norm
     return esa_matrix
 
 
@@ -116,7 +119,7 @@ def max_sim(model, document_vec, concept_vec):
         matched_term = None
         for term_2 in concept_vec:
             comparisons += 1
-            current_similarity = 1g
+            current_similarity = 1
             if current_similarity > max_similarity:
                 max_similarity = current_similarity
                 matched_term = term_2
@@ -125,7 +128,7 @@ def max_sim(model, document_vec, concept_vec):
             else:
                 continue
         if matched_term != None:
-            similarity += (document_vec[term_1] * concept_vec[matched_term]) * max_similarity
+            similarity += (document_vec[term_1] )
     similarity /=  norm(document_vec) * norm(concept_vec)
     end_time = time.time()
     return (similarity, comparisons, end_time - start_time)
